# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cfbd.api_client import ApiClient


class GamesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_advanced_box_score(self, game_id, **kwargs):  # noqa: E501
        """Advanced box scores  # noqa: E501

        Get advanced box score data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advanced_box_score(game_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int game_id: Game id parameters (required)
        :return: BoxScore
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_advanced_box_score_with_http_info(game_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_advanced_box_score_with_http_info(game_id, **kwargs)  # noqa: E501
            return data

    def get_advanced_box_score_with_http_info(self, game_id, **kwargs):  # noqa: E501
        """Advanced box scores  # noqa: E501

        Get advanced box score data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advanced_box_score_with_http_info(game_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int game_id: Game id parameters (required)
        :return: BoxScore
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['game_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_advanced_box_score" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'game_id' is set
        if self.api_client.client_side_validation and ('game_id' not in params or
                                                       params['game_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `game_id` when calling `get_advanced_box_score`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'game_id' in params:
            query_params.append(('gameId', params['game_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/game/box/advanced', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BoxScore',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_calendar(self, year, **kwargs):  # noqa: E501
        """Season calendar  # noqa: E501

        Get calendar of weeks by season  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_calendar(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required)
        :return: list[Week]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_calendar_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_calendar_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_calendar_with_http_info(self, year, **kwargs):  # noqa: E501
        """Season calendar  # noqa: E501

        Get calendar of weeks by season  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_calendar_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required)
        :return: list[Week]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_calendar" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if self.api_client.client_side_validation and ('year' not in params or
                                                       params['year'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `year` when calling `get_calendar`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/calendar', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Week]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_game_media(self, year, **kwargs):  # noqa: E501
        """Game media information and schedules  # noqa: E501

        Game media information (TV, radio, etc)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_game_media(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular, postseason, or both)
        :param str team: Team filter
        :param str conference: Conference filter
        :param str media_type: Media type filter (tv, radio, web, ppv, or mobile)
        :return: list[GameMedia]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_game_media_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_game_media_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_game_media_with_http_info(self, year, **kwargs):  # noqa: E501
        """Game media information and schedules  # noqa: E501

        Game media information (TV, radio, etc)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_game_media_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular, postseason, or both)
        :param str team: Team filter
        :param str conference: Conference filter
        :param str media_type: Media type filter (tv, radio, web, ppv, or mobile)
        :return: list[GameMedia]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'season_type', 'team', 'conference', 'media_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_game_media" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if self.api_client.client_side_validation and ('year' not in params or
                                                       params['year'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `year` when calling `get_game_media`")  # noqa: E501

        if self.api_client.client_side_validation and ('year' in params and params['year'] < 2001):  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_game_media`, must be a value greater than or equal to `2001`")  # noqa: E501
        if self.api_client.client_side_validation and ('week' in params and params['week'] > 16):  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_game_media`, must be a value less than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'media_type' in params:
            query_params.append(('mediaType', params['media_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/games/media', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GameMedia]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_games(self, year, **kwargs):  # noqa: E501
        """Games and results  # noqa: E501

        Get game results  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_games(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team
        :param str home: Home team filter
        :param str away: Away team filter
        :param str conference: Conference abbreviation filter
        :param int id: id filter for querying a single game
        :return: list[Game]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_games_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_games_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_games_with_http_info(self, year, **kwargs):  # noqa: E501
        """Games and results  # noqa: E501

        Get game results  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_games_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team
        :param str home: Home team filter
        :param str away: Away team filter
        :param str conference: Conference abbreviation filter
        :param int id: id filter for querying a single game
        :return: list[Game]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'season_type', 'team', 'home', 'away', 'conference', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_games" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if self.api_client.client_side_validation and ('year' not in params or
                                                       params['year'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `year` when calling `get_games`")  # noqa: E501

        if self.api_client.client_side_validation and ('year' in params and params['year'] < 1869):  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_games`, must be a value greater than or equal to `1869`")  # noqa: E501
        if self.api_client.client_side_validation and ('week' in params and params['week'] > 16):  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_games`, must be a value less than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('week' in params and params['week'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_games`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'home' in params:
            query_params.append(('home', params['home']))  # noqa: E501
        if 'away' in params:
            query_params.append(('away', params['away']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'id' in params:
            query_params.append(('id', params['id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/games', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Game]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_player_game_stats(self, year, **kwargs):  # noqa: E501
        """Player game stats  # noqa: E501

        Player stats broken down by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_player_game_stats(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param str category: Category filter (e.g defensive)
        :param int game_id: Game id filter
        :return: list[PlayerGame]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_player_game_stats_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_player_game_stats_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_player_game_stats_with_http_info(self, year, **kwargs):  # noqa: E501
        """Player game stats  # noqa: E501

        Player stats broken down by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_player_game_stats_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param str category: Category filter (e.g defensive)
        :param int game_id: Game id filter
        :return: list[PlayerGame]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'season_type', 'team', 'conference', 'category', 'game_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_player_game_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if self.api_client.client_side_validation and ('year' not in params or
                                                       params['year'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `year` when calling `get_player_game_stats`")  # noqa: E501

        if self.api_client.client_side_validation and ('week' in params and params['week'] > 16):  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_player_game_stats`, must be a value less than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'category' in params:
            query_params.append(('category', params['category']))  # noqa: E501
        if 'game_id' in params:
            query_params.append(('gameId', params['game_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/games/players', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PlayerGame]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_game_stats(self, year, **kwargs):  # noqa: E501
        """Team game stats  # noqa: E501

        Team stats broken down by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_game_stats(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param int game_id: Game id filter
        :return: list[TeamGame]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_game_stats_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_team_game_stats_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_team_game_stats_with_http_info(self, year, **kwargs):  # noqa: E501
        """Team game stats  # noqa: E501

        Team stats broken down by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_game_stats_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param int game_id: Game id filter
        :return: list[TeamGame]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'season_type', 'team', 'conference', 'game_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_game_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if self.api_client.client_side_validation and ('year' not in params or
                                                       params['year'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `year` when calling `get_team_game_stats`")  # noqa: E501

        if self.api_client.client_side_validation and ('year' in params and params['year'] < 2001):  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_team_game_stats`, must be a value greater than or equal to `2001`")  # noqa: E501
        if self.api_client.client_side_validation and ('week' in params and params['week'] > 16):  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_team_game_stats`, must be a value less than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('week' in params and params['week'] < 1):  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_team_game_stats`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'game_id' in params:
            query_params.append(('gameId', params['game_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/games/teams', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamGame]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_records(self, **kwargs):  # noqa: E501
        """Team records  # noqa: E501

        Get team records by year  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_records(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param str team: Team filter
        :param str conference: Conference filter
        :return: list[TeamRecord]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_records_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_team_records_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_team_records_with_http_info(self, **kwargs):  # noqa: E501
        """Team records  # noqa: E501

        Get team records by year  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_records_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param str team: Team filter
        :param str conference: Conference filter
        :return: list[TeamRecord]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'team', 'conference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_records" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('year' in params and params['year'] < 1869):  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_team_records`, must be a value greater than or equal to `1869`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/records', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamRecord]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cfbd.configuration import Configuration


class PositionGroupRecruitingRating(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'team': 'str',
        'conference': 'str',
        'position_group': 'str',
        'average_rating': 'float',
        'total_rating': 'float',
        'commits': 'float',
        'average_stars': 'float'
    }

    attribute_map = {
        'team': 'team',
        'conference': 'conference',
        'position_group': 'positionGroup',
        'average_rating': 'averageRating',
        'total_rating': 'totalRating',
        'commits': 'commits',
        'average_stars': 'averageStars'
    }

    def __init__(self, team=None, conference=None, position_group=None, average_rating=None, total_rating=None, commits=None, average_stars=None, _configuration=None):  # noqa: E501
        """PositionGroupRecruitingRating - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._team = None
        self._conference = None
        self._position_group = None
        self._average_rating = None
        self._total_rating = None
        self._commits = None
        self._average_stars = None
        self.discriminator = None

        if team is not None:
            self.team = team
        if conference is not None:
            self.conference = conference
        if position_group is not None:
            self.position_group = position_group
        if average_rating is not None:
            self.average_rating = average_rating
        if total_rating is not None:
            self.total_rating = total_rating
        if commits is not None:
            self.commits = commits
        if average_stars is not None:
            self.average_stars = average_stars

    @property
    def team(self):
        """Gets the team of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The team of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this PositionGroupRecruitingRating.


        :param team: The team of this PositionGroupRecruitingRating.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def conference(self):
        """Gets the conference of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The conference of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: str
        """
        return self._conference

    @conference.setter
    def conference(self, conference):
        """Sets the conference of this PositionGroupRecruitingRating.


        :param conference: The conference of this PositionGroupRecruitingRating.  # noqa: E501
        :type: str
        """

        self._conference = conference

    @property
    def position_group(self):
        """Gets the position_group of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The position_group of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: str
        """
        return self._position_group

    @position_group.setter
    def position_group(self, position_group):
        """Sets the position_group of this PositionGroupRecruitingRating.


        :param position_group: The position_group of this PositionGroupRecruitingRating.  # noqa: E501
        :type: str
        """

        self._position_group = position_group

    @property
    def average_rating(self):
        """Gets the average_rating of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The average_rating of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: float
        """
        return self._average_rating

    @average_rating.setter
    def average_rating(self, average_rating):
        """Sets the average_rating of this PositionGroupRecruitingRating.


        :param average_rating: The average_rating of this PositionGroupRecruitingRating.  # noqa: E501
        :type: float
        """

        self._average_rating = average_rating

    @property
    def total_rating(self):
        """Gets the total_rating of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The total_rating of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: float
        """
        return self._total_rating

    @total_rating.setter
    def total_rating(self, total_rating):
        """Sets the total_rating of this PositionGroupRecruitingRating.


        :param total_rating: The total_rating of this PositionGroupRecruitingRating.  # noqa: E501
        :type: float
        """

        self._total_rating = total_rating

    @property
    def commits(self):
        """Gets the commits of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The commits of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: float
        """
        return self._commits

    @commits.setter
    def commits(self, commits):
        """Sets the commits of this PositionGroupRecruitingRating.


        :param commits: The commits of this PositionGroupRecruitingRating.  # noqa: E501
        :type: float
        """

        self._commits = commits

    @property
    def average_stars(self):
        """Gets the average_stars of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The average_stars of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: float
        """
        return self._average_stars

    @average_stars.setter
    def average_stars(self, average_stars):
        """Sets the average_stars of this PositionGroupRecruitingRating.


        :param average_stars: The average_stars of this PositionGroupRecruitingRating.  # noqa: E501
        :type: float
        """

        self._average_stars = average_stars

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PositionGroupRecruitingRating, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PositionGroupRecruitingRating):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PositionGroupRecruitingRating):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cfbd.configuration import Configuration


class PlayerSearchResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'team': 'str',
        'name': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'weight': 'int',
        'height': 'int',
        'jersey': 'int',
        'position': 'str',
        'hometown': 'str',
        'team_color': 'str',
        'team_color_secondary': 'str'
    }

    attribute_map = {
        'id': 'id',
        'team': 'team',
        'name': 'name',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'weight': 'weight',
        'height': 'height',
        'jersey': 'jersey',
        'position': 'position',
        'hometown': 'hometown',
        'team_color': 'teamColor',
        'team_color_secondary': 'teamColorSecondary'
    }

    def __init__(self, id=None, team=None, name=None, first_name=None, last_name=None, weight=None, height=None, jersey=None, position=None, hometown=None, team_color=None, team_color_secondary=None, _configuration=None):  # noqa: E501
        """PlayerSearchResult - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._team = None
        self._name = None
        self._first_name = None
        self._last_name = None
        self._weight = None
        self._height = None
        self._jersey = None
        self._position = None
        self._hometown = None
        self._team_color = None
        self._team_color_secondary = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if team is not None:
            self.team = team
        if name is not None:
            self.name = name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if weight is not None:
            self.weight = weight
        if height is not None:
            self.height = height
        if jersey is not None:
            self.jersey = jersey
        if position is not None:
            self.position = position
        if hometown is not None:
            self.hometown = hometown
        if team_color is not None:
            self.team_color = team_color
        if team_color_secondary is not None:
            self.team_color_secondary = team_color_secondary

    @property
    def id(self):
        """Gets the id of this PlayerSearchResult.  # noqa: E501


        :return: The id of this PlayerSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PlayerSearchResult.


        :param id: The id of this PlayerSearchResult.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def team(self):
        """Gets the team of this PlayerSearchResult.  # noqa: E501


        :return: The team of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this PlayerSearchResult.


        :param team: The team of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def name(self):
        """Gets the name of this PlayerSearchResult.  # noqa: E501


        :return: The name of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PlayerSearchResult.


        :param name: The name of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def first_name(self):
        """Gets the first_name of this PlayerSearchResult.  # noqa: E501


        :return: The first_name of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this PlayerSearchResult.


        :param first_name: The first_name of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this PlayerSearchResult.  # noqa: E501


        :return: The last_name of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this PlayerSearchResult.


        :param last_name: The last_name of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def weight(self):
        """Gets the weight of this PlayerSearchResult.  # noqa: E501


        :return: The weight of this PlayerSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this PlayerSearchResult.


        :param weight: The weight of this PlayerSearchResult.  # noqa: E501
        :type: int
        """

        self._weight = weight

    @property
    def height(self):
        """Gets the height of this PlayerSearchResult.  # noqa: E501


        :return: The height of this PlayerSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this PlayerSearchResult.


        :param height: The height of this PlayerSearchResult.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def jersey(self):
        """Gets the jersey of this PlayerSearchResult.  # noqa: E501


        :return: The jersey of this PlayerSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._jersey

    @jersey.setter
    def jersey(self, jersey):
        """Sets the jersey of this PlayerSearchResult.


        :param jersey: The jersey of this PlayerSearchResult.  # noqa: E501
        :type: int
        """

        self._jersey = jersey

    @property
    def position(self):
        """Gets the position of this PlayerSearchResult.  # noqa: E501


        :return: The position of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this PlayerSearchResult.


        :param position: The position of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._position = position

    @property
    def hometown(self):
        """Gets the hometown of this PlayerSearchResult.  # noqa: E501


        :return: The hometown of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._hometown

    @hometown.setter
    def hometown(self, hometown):
        """Sets the hometown of this PlayerSearchResult.


        :param hometown: The hometown of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._hometown = hometown

    @property
    def team_color(self):
        """Gets the team_color of this PlayerSearchResult.  # noqa: E501


        :return: The team_color of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._team_color

    @team_color.setter
    def team_color(self, team_color):
        """Sets the team_color of this PlayerSearchResult.


        :param team_color: The team_color of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._team_color = team_color

    @property
    def team_color_secondary(self):
        """Gets the team_color_secondary of this PlayerSearchResult.  # noqa: E501


        :return: The team_color_secondary of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._team_color_secondary

    @team_color_secondary.setter
    def team_color_secondary(self, team_color_secondary):
        """Sets the team_color_secondary of this PlayerSearchResult.


        :param team_color_secondary: The team_color_secondary of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._team_color_secondary = team_color_secondary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayerSearchResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayerSearchResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlayerSearchResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.api.metrics_api import MetricsApi  # noqa: E501
from cfbd.rest import ApiException


class TestMetricsApi(unittest.TestCase):
    """MetricsApi unit test stubs"""

    def setUp(self):
        self.api = cfbd.api.metrics_api.MetricsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_game_ppa(self):
        """Test case for get_game_ppa

        Team Predicated Points Added (PPA/EPA) by game  # noqa: E501
        """
        pass

    def test_get_player_game_ppa(self):
        """Test case for get_player_game_ppa

        Player Predicated Points Added (PPA/EPA) broken down by game  # noqa: E501
        """
        pass

    def test_get_player_season_ppa(self):
        """Test case for get_player_season_ppa

        Player Predicated Points Added (PPA/EPA) broken down by season  # noqa: E501
        """
        pass

    def test_get_predicted_points(self):
        """Test case for get_predicted_points

        Predicted Points (i.e. Expected Points or EP)  # noqa: E501
        """
        pass

    def test_get_pregame_win_probabilities(self):
        """Test case for get_pregame_win_probabilities

        Pregame win probability data  # noqa: E501
        """
        pass

    def test_get_team_ppa(self):
        """Test case for get_team_ppa

        Predicted Points Added (PPA/EPA) data by team  # noqa: E501
        """
        pass

    def test_get_win_probability_data(self):
        """Test case for get_win_probability_data

        Win probability chart data  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.api.coaches_api import CoachesApi  # noqa: E501
from cfbd.rest import ApiException


class TestCoachesApi(unittest.TestCase):
    """CoachesApi unit test stubs"""

    def setUp(self):
        self.api = cfbd.api.coaches_api.CoachesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_coaches(self):
        """Test case for get_coaches

        Coaching records and history  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cfbd.configuration import Configuration


class Play(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'drive_id': 'int',
        'game_id': 'int',
        'drive_number': 'int',
        'play_number': 'int',
        'offense': 'str',
        'offense_conference': 'str',
        'offense_score': 'int',
        'defense': 'str',
        'home': 'str',
        'away': 'str',
        'defense_conference': 'str',
        'defense_score': 'int',
        'period': 'int',
        'clock': 'object',
        'offense_timeouts': 'int',
        'defense_timeouts': 'int',
        'yard_line': 'int',
        'yards_to_goal': 'int',
        'down': 'int',
        'distance': 'int',
        'yards_gained': 'int',
        'scoring': 'bool',
        'play_type': 'str',
        'play_text': 'str',
        'ppa': 'float'
    }

    attribute_map = {
        'id': 'id',
        'drive_id': 'drive_id',
        'game_id': 'game_id',
        'drive_number': 'drive_number',
        'play_number': 'play_number',
        'offense': 'offense',
        'offense_conference': 'offense_conference',
        'offense_score': 'offense_score',
        'defense': 'defense',
        'home': 'home',
        'away': 'away',
        'defense_conference': 'defense_conference',
        'defense_score': 'defense_score',
        'period': 'period',
        'clock': 'clock',
        'offense_timeouts': 'offense_timeouts',
        'defense_timeouts': 'defense_timeouts',
        'yard_line': 'yard_line',
        'yards_to_goal': 'yards_to_goal',
        'down': 'down',
        'distance': 'distance',
        'yards_gained': 'yards_gained',
        'scoring': 'scoring',
        'play_type': 'play_type',
        'play_text': 'play_text',
        'ppa': 'ppa'
    }

    def __init__(self, id=None, drive_id=None, game_id=None, drive_number=None, play_number=None, offense=None, offense_conference=None, offense_score=None, defense=None, home=None, away=None, defense_conference=None, defense_score=None, period=None, clock=None, offense_timeouts=None, defense_timeouts=None, yard_line=None, yards_to_goal=None, down=None, distance=None, yards_gained=None, scoring=None, play_type=None, play_text=None, ppa=None, _configuration=None):  # noqa: E501
        """Play - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._drive_id = None
        self._game_id = None
        self._drive_number = None
        self._play_number = None
        self._offense = None
        self._offense_conference = None
        self._offense_score = None
        self._defense = None
        self._home = None
        self._away = None
        self._defense_conference = None
        self._defense_score = None
        self._period = None
        self._clock = None
        self._offense_timeouts = None
        self._defense_timeouts = None
        self._yard_line = None
        self._yards_to_goal = None
        self._down = None
        self._distance = None
        self._yards_gained = None
        self._scoring = None
        self._play_type = None
        self._play_text = None
        self._ppa = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if drive_id is not None:
            self.drive_id = drive_id
        if game_id is not None:
            self.game_id = game_id
        if drive_number is not None:
            self.drive_number = drive_number
        if play_number is not None:
            self.play_number = play_number
        if offense is not None:
            self.offense = offense
        if offense_conference is not None:
            self.offense_conference = offense_conference
        if offense_score is not None:
            self.offense_score = offense_score
        if defense is not None:
            self.defense = defense
        if home is not None:
            self.home = home
        if away is not None:
            self.away = away
        if defense_conference is not None:
            self.defense_conference = defense_conference
        if defense_score is not None:
            self.defense_score = defense_score
        if period is not None:
            self.period = period
        if clock is not None:
            self.clock = clock
        if offense_timeouts is not None:
            self.offense_timeouts = offense_timeouts
        if defense_timeouts is not None:
            self.defense_timeouts = defense_timeouts
        if yard_line is not None:
            self.yard_line = yard_line
        if yards_to_goal is not None:
            self.yards_to_goal = yards_to_goal
        if down is not None:
            self.down = down
        if distance is not None:
            self.distance = distance
        if yards_gained is not None:
            self.yards_gained = yards_gained
        if scoring is not None:
            self.scoring = scoring
        if play_type is not None:
            self.play_type = play_type
        if play_text is not None:
            self.play_text = play_text
        if ppa is not None:
            self.ppa = ppa

    @property
    def id(self):
        """Gets the id of this Play.  # noqa: E501


        :return: The id of this Play.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Play.


        :param id: The id of this Play.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def drive_id(self):
        """Gets the drive_id of this Play.  # noqa: E501


        :return: The drive_id of this Play.  # noqa: E501
        :rtype: int
        """
        return self._drive_id

    @drive_id.setter
    def drive_id(self, drive_id):
        """Sets the drive_id of this Play.


        :param drive_id: The drive_id of this Play.  # noqa: E501
        :type: int
        """

        self._drive_id = drive_id

    @property
    def game_id(self):
        """Gets the game_id of this Play.  # noqa: E501


        :return: The game_id of this Play.  # noqa: E501
        :rtype: int
        """
        return self._game_id

    @game_id.setter
    def game_id(self, game_id):
        """Sets the game_id of this Play.


        :param game_id: The game_id of this Play.  # noqa: E501
        :type: int
        """

        self._game_id = game_id

    @property
    def drive_number(self):
        """Gets the drive_number of this Play.  # noqa: E501


        :return: The drive_number of this Play.  # noqa: E501
        :rtype: int
        """
        return self._drive_number

    @drive_number.setter
    def drive_number(self, drive_number):
        """Sets the drive_number of this Play.


        :param drive_number: The drive_number of this Play.  # noqa: E501
        :type: int
        """

        self._drive_number = drive_number

    @property
    def play_number(self):
        """Gets the play_number of this Play.  # noqa: E501


        :return: The play_number of this Play.  # noqa: E501
        :rtype: int
        """
        return self._play_number

    @play_number.setter
    def play_number(self, play_number):
        """Sets the play_number of this Play.


        :param play_number: The play_number of this Play.  # noqa: E501
        :type: int
        """

        self._play_number = play_number

    @property
    def offense(self):
        """Gets the offense of this Play.  # noqa: E501


        :return: The offense of this Play.  # noqa: E501
        :rtype: str
        """
        return self._offense

    @offense.setter
    def offense(self, offense):
        """Sets the offense of this Play.


        :param offense: The offense of this Play.  # noqa: E501
        :type: str
        """

        self._offense = offense

    @property
    def offense_conference(self):
        """Gets the offense_conference of this Play.  # noqa: E501


        :return: The offense_conference of this Play.  # noqa: E501
        :rtype: str
        """
        return self._offense_conference

    @offense_conference.setter
    def offense_conference(self, offense_conference):
        """Sets the offense_conference of this Play.


        :param offense_conference: The offense_conference of this Play.  # noqa: E501
        :type: str
        """

        self._offense_conference = offense_conference

    @property
    def offense_score(self):
        """Gets the offense_score of this Play.  # noqa: E501


        :return: The offense_score of this Play.  # noqa: E501
        :rtype: int
        """
        return self._offense_score

    @offense_score.setter
    def offense_score(self, offense_score):
        """Sets the offense_score of this Play.


        :param offense_score: The offense_score of this Play.  # noqa: E501
        :type: int
        """

        self._offense_score = offense_score

    @property
    def defense(self):
        """Gets the defense of this Play.  # noqa: E501


        :return: The defense of this Play.  # noqa: E501
        :rtype: str
        """
        return self._defense

    @defense.setter
    def defense(self, defense):
        """Sets the defense of this Play.


        :param defense: The defense of this Play.  # noqa: E501
        :type: str
        """

        self._defense = defense

    @property
    def home(self):
        """Gets the home of this Play.  # noqa: E501


        :return: The home of this Play.  # noqa: E501
        :rtype: str
        """
        return self._home

    @home.setter
    def home(self, home):
        """Sets the home of this Play.


        :param home: The home of this Play.  # noqa: E501
        :type: str
        """

        self._home = home

    @property
    def away(self):
        """Gets the away of this Play.  # noqa: E501


        :return: The away of this Play.  # noqa: E501
        :rtype: str
        """
        return self._away

    @away.setter
    def away(self, away):
        """Sets the away of this Play.


        :param away: The away of this Play.  # noqa: E501
        :type: str
        """

        self._away = away

    @property
    def defense_conference(self):
        """Gets the defense_conference of this Play.  # noqa: E501


        :return: The defense_conference of this Play.  # noqa: E501
        :rtype: str
        """
        return self._defense_conference

    @defense_conference.setter
    def defense_conference(self, defense_conference):
        """Sets the defense_conference of this Play.


        :param defense_conference: The defense_conference of this Play.  # noqa: E501
        :type: str
        """

        self._defense_conference = defense_conference

    @property
    def defense_score(self):
        """Gets the defense_score of this Play.  # noqa: E501


        :return: The defense_score of this Play.  # noqa: E501
        :rtype: int
        """
        return self._defense_score

    @defense_score.setter
    def defense_score(self, defense_score):
        """Sets the defense_score of this Play.


        :param defense_score: The defense_score of this Play.  # noqa: E501
        :type: int
        """

        self._defense_score = defense_score

    @property
    def period(self):
        """Gets the period of this Play.  # noqa: E501


        :return: The period of this Play.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this Play.


        :param period: The period of this Play.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def clock(self):
        """Gets the clock of this Play.  # noqa: E501


        :return: The clock of this Play.  # noqa: E501
        :rtype: object
        """
        return self._clock

    @clock.setter
    def clock(self, clock):
        """Sets the clock of this Play.


        :param clock: The clock of this Play.  # noqa: E501
        :type: object
        """

        self._clock = clock

    @property
    def offense_timeouts(self):
        """Gets the offense_timeouts of this Play.  # noqa: E501


        :return: The offense_timeouts of this Play.  # noqa: E501
        :rtype: int
        """
        return self._offense_timeouts

    @offense_timeouts.setter
    def offense_timeouts(self, offense_timeouts):
        """Sets the offense_timeouts of this Play.


        :param offense_timeouts: The offense_timeouts of this Play.  # noqa: E501
        :type: int
        """

        self._offense_timeouts = offense_timeouts

    @property
    def defense_timeouts(self):
        """Gets the defense_timeouts of this Play.  # noqa: E501


        :return: The defense_timeouts of this Play.  # noqa: E501
        :rtype: int
        """
        return self._defense_timeouts

    @defense_timeouts.setter
    def defense_timeouts(self, defense_timeouts):
        """Sets the defense_timeouts of this Play.


        :param defense_timeouts: The defense_timeouts of this Play.  # noqa: E501
        :type: int
        """

        self._defense_timeouts = defense_timeouts

    @property
    def yard_line(self):
        """Gets the yard_line of this Play.  # noqa: E501


        :return: The yard_line of this Play.  # noqa: E501
        :rtype: int
        """
        return self._yard_line

    @yard_line.setter
    def yard_line(self, yard_line):
        """Sets the yard_line of this Play.


        :param yard_line: The yard_line of this Play.  # noqa: E501
        :type: int
        """

        self._yard_line = yard_line

    @property
    def yards_to_goal(self):
        """Gets the yards_to_goal of this Play.  # noqa: E501


        :return: The yards_to_goal of this Play.  # noqa: E501
        :rtype: int
        """
        return self._yards_to_goal

    @yards_to_goal.setter
    def yards_to_goal(self, yards_to_goal):
        """Sets the yards_to_goal of this Play.


        :param yards_to_goal: The yards_to_goal of this Play.  # noqa: E501
        :type: int
        """

        self._yards_to_goal = yards_to_goal

    @property
    def down(self):
        """Gets the down of this Play.  # noqa: E501


        :return: The down of this Play.  # noqa: E501
        :rtype: int
        """
        return self._down

    @down.setter
    def down(self, down):
        """Sets the down of this Play.


        :param down: The down of this Play.  # noqa: E501
        :type: int
        """

        self._down = down

    @property
    def distance(self):
        """Gets the distance of this Play.  # noqa: E501


        :return: The distance of this Play.  # noqa: E501
        :rtype: int
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this Play.


        :param distance: The distance of this Play.  # noqa: E501
        :type: int
        """

        self._distance = distance

    @property
    def yards_gained(self):
        """Gets the yards_gained of this Play.  # noqa: E501


        :return: The yards_gained of this Play.  # noqa: E501
        :rtype: int
        """
        return self._yards_gained

    @yards_gained.setter
    def yards_gained(self, yards_gained):
        """Sets the yards_gained of this Play.


        :param yards_gained: The yards_gained of this Play.  # noqa: E501
        :type: int
        """

        self._yards_gained = yards_gained

    @property
    def scoring(self):
        """Gets the scoring of this Play.  # noqa: E501


        :return: The scoring of this Play.  # noqa: E501
        :rtype: bool
        """
        return self._scoring

    @scoring.setter
    def scoring(self, scoring):
        """Sets the scoring of this Play.


        :param scoring: The scoring of this Play.  # noqa: E501
        :type: bool
        """

        self._scoring = scoring

    @property
    def play_type(self):
        """Gets the play_type of this Play.  # noqa: E501


        :return: The play_type of this Play.  # noqa: E501
        :rtype: str
        """
        return self._play_type

    @play_type.setter
    def play_type(self, play_type):
        """Sets the play_type of this Play.


        :param play_type: The play_type of this Play.  # noqa: E501
        :type: str
        """

        self._play_type = play_type

    @property
    def play_text(self):
        """Gets the play_text of this Play.  # noqa: E501


        :return: The play_text of this Play.  # noqa: E501
        :rtype: str
        """
        return self._play_text

    @play_text.setter
    def play_text(self, play_text):
        """Sets the play_text of this Play.


        :param play_text: The play_text of this Play.  # noqa: E501
        :type: str
        """

        self._play_text = play_text

    @property
    def ppa(self):
        """Gets the ppa of this Play.  # noqa: E501


        :return: The ppa of this Play.  # noqa: E501
        :rtype: float
        """
        return self._ppa

    @ppa.setter
    def ppa(self, ppa):
        """Sets the ppa of this Play.


        :param ppa: The ppa of this Play.  # noqa: E501
        :type: float
        """

        self._ppa = ppa

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Play, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Play):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Play):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cfbd.api_client import ApiClient


class RecruitingApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_recruiting_groups(self, **kwargs):  # noqa: E501
        """Recruit position group ratings  # noqa: E501

        Gets a list of aggregated statistics by team and position grouping  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recruiting_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_year: Starting year
        :param int end_year: Ending year
        :param str team: Team filter
        :param str conference: conference filter
        :return: list[PositionGroupRecruitingRating]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_recruiting_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_recruiting_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_recruiting_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Recruit position group ratings  # noqa: E501

        Gets a list of aggregated statistics by team and position grouping  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recruiting_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_year: Starting year
        :param int end_year: Ending year
        :param str team: Team filter
        :param str conference: conference filter
        :return: list[PositionGroupRecruitingRating]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_year', 'end_year', 'team', 'conference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recruiting_groups" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start_year' in params and params['start_year'] < 2000):  # noqa: E501
            raise ValueError("Invalid value for parameter `start_year` when calling `get_recruiting_groups`, must be a value greater than or equal to `2000`")  # noqa: E501
        if self.api_client.client_side_validation and ('end_year' in params and params['end_year'] < 2000):  # noqa: E501
            raise ValueError("Invalid value for parameter `end_year` when calling `get_recruiting_groups`, must be a value greater than or equal to `2000`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_year' in params:
            query_params.append(('startYear', params['start_year']))  # noqa: E501
        if 'end_year' in params:
            query_params.append(('endYear', params['end_year']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/recruiting/groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PositionGroupRecruitingRating]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_recruiting_players(self, **kwargs):  # noqa: E501
        """Player recruiting ratings and rankings  # noqa: E501

        Get player recruiting rankings and data. Requires either a year or team to be specified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recruiting_players(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Recruiting class year (required if team no specified)
        :param str classification: Type of recruit (HighSchool, JUCO, PrepSchool)
        :param str position: Position abbreviation filter
        :param str state: State or province abbreviation filter
        :param str team: Committed team filter (required if year not specified)
        :return: list[Recruit]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_recruiting_players_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_recruiting_players_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_recruiting_players_with_http_info(self, **kwargs):  # noqa: E501
        """Player recruiting ratings and rankings  # noqa: E501

        Get player recruiting rankings and data. Requires either a year or team to be specified.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recruiting_players_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Recruiting class year (required if team no specified)
        :param str classification: Type of recruit (HighSchool, JUCO, PrepSchool)
        :param str position: Position abbreviation filter
        :param str state: State or province abbreviation filter
        :param str team: Committed team filter (required if year not specified)
        :return: list[Recruit]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'classification', 'position', 'state', 'team']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recruiting_players" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('year' in params and params['year'] < 2000):  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_recruiting_players`, must be a value greater than or equal to `2000`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'classification' in params:
            query_params.append(('classification', params['classification']))  # noqa: E501
        if 'position' in params:
            query_params.append(('position', params['position']))  # noqa: E501
        if 'state' in params:
            query_params.append(('state', params['state']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/recruiting/players', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Recruit]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_recruiting_teams(self, **kwargs):  # noqa: E501
        """Team recruiting rankings and ratings  # noqa: E501

        Team recruiting rankings  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recruiting_teams(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Recruiting class year
        :param str team: Team filter
        :return: list[TeamRecruitingRank]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_recruiting_teams_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_recruiting_teams_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_recruiting_teams_with_http_info(self, **kwargs):  # noqa: E501
        """Team recruiting rankings and ratings  # noqa: E501

        Team recruiting rankings  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_recruiting_teams_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Recruiting class year
        :param str team: Team filter
        :return: list[TeamRecruitingRank]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'team']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recruiting_teams" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('year' in params and params['year'] < 2000):  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_recruiting_teams`, must be a value greater than or equal to `2000`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/recruiting/teams', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamRecruitingRank]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.api.conferences_api import ConferencesApi  # noqa: E501
from cfbd.rest import ApiException


class TestConferencesApi(unittest.TestCase):
    """ConferencesApi unit test stubs"""

    def setUp(self):
        self.api = cfbd.api.conferences_api.ConferencesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_conferences(self):
        """Test case for get_conferences

        Conferences  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.4.1
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BoxScoreTeamsOverall(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total': 'float',
        'quarter1': 'float',
        'quarter2': 'float',
        'quarter3': 'float',
        'quarter4': 'float'
    }

    attribute_map = {
        'total': 'total',
        'quarter1': 'quarter1',
        'quarter2': 'quarter2',
        'quarter3': 'quarter3',
        'quarter4': 'quarter4'
    }

    def __init__(self, total=None, quarter1=None, quarter2=None, quarter3=None, quarter4=None):  # noqa: E501
        """BoxScoreTeamsOverall - a model defined in Swagger"""  # noqa: E501

        self._total = None
        self._quarter1 = None
        self._quarter2 = None
        self._quarter3 = None
        self._quarter4 = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if quarter1 is not None:
            self.quarter1 = quarter1
        if quarter2 is not None:
            self.quarter2 = quarter2
        if quarter3 is not None:
            self.quarter3 = quarter3
        if quarter4 is not None:
            self.quarter4 = quarter4

    @property
    def total(self):
        """Gets the total of this BoxScoreTeamsOverall.  # noqa: E501


        :return: The total of this BoxScoreTeamsOverall.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this BoxScoreTeamsOverall.


        :param total: The total of this BoxScoreTeamsOverall.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def quarter1(self):
        """Gets the quarter1 of this BoxScoreTeamsOverall.  # noqa: E501


        :return: The quarter1 of this BoxScoreTeamsOverall.  # noqa: E501
        :rtype: float
        """
        return self._quarter1

    @quarter1.setter
    def quarter1(self, quarter1):
        """Sets the quarter1 of this BoxScoreTeamsOverall.


        :param quarter1: The quarter1 of this BoxScoreTeamsOverall.  # noqa: E501
        :type: float
        """

        self._quarter1 = quarter1

    @property
    def quarter2(self):
        """Gets the quarter2 of this BoxScoreTeamsOverall.  # noqa: E501


        :return: The quarter2 of this BoxScoreTeamsOverall.  # noqa: E501
        :rtype: float
        """
        return self._quarter2

    @quarter2.setter
    def quarter2(self, quarter2):
        """Sets the quarter2 of this BoxScoreTeamsOverall.


        :param quarter2: The quarter2 of this BoxScoreTeamsOverall.  # noqa: E501
        :type: float
        """

        self._quarter2 = quarter2

    @property
    def quarter3(self):
        """Gets the quarter3 of this BoxScoreTeamsOverall.  # noqa: E501


        :return: The quarter3 of this BoxScoreTeamsOverall.  # noqa: E501
        :rtype: float
        """
        return self._quarter3

    @quarter3.setter
    def quarter3(self, quarter3):
        """Sets the quarter3 of this BoxScoreTeamsOverall.


        :param quarter3: The quarter3 of this BoxScoreTeamsOverall.  # noqa: E501
        :type: float
        """

        self._quarter3 = quarter3

    @property
    def quarter4(self):
        """Gets the quarter4 of this BoxScoreTeamsOverall.  # noqa: E501


        :return: The quarter4 of this BoxScoreTeamsOverall.  # noqa: E501
        :rtype: float
        """
        return self._quarter4

    @quarter4.setter
    def quarter4(self, quarter4):
        """Sets the quarter4 of this BoxScoreTeamsOverall.


        :param quarter4: The quarter4 of this BoxScoreTeamsOverall.  # noqa: E501
        :type: float
        """

        self._quarter4 = quarter4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BoxScoreTeamsOverall, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BoxScoreTeamsOverall):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "cfbd"
VERSION = "3.2.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="College Football Data API",
    author_email="admin@collegefootballdata.com",
    url="https://github.com/CFBD/cfbd-python",
    keywords=["Swagger", "College Football Data API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \&quot;Bearer \&quot; prepended (e.g. \&quot;Bearer your_key\&quot;).  # noqa: E501
    """
)



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.4.1
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.models.drive_start_time import DriveStartTime  # noqa: E501
from cfbd.rest import ApiException


class TestDriveStartTime(unittest.TestCase):
    """DriveStartTime unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDriveStartTime(self):
        """Test DriveStartTime"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cfbd.models.drive_start_time.DriveStartTime()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cfbd.configuration import Configuration


class PregameWP(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'season': 'int',
        'season_type': 'str',
        'week': 'int',
        'game_id': 'int',
        'home_team': 'str',
        'away_team': 'str',
        'spread': 'float',
        'home_win_prob': 'float'
    }

    attribute_map = {
        'season': 'season',
        'season_type': 'seasonType',
        'week': 'week',
        'game_id': 'gameId',
        'home_team': 'homeTeam',
        'away_team': 'awayTeam',
        'spread': 'spread',
        'home_win_prob': 'homeWinProb'
    }

    def __init__(self, season=None, season_type=None, week=None, game_id=None, home_team=None, away_team=None, spread=None, home_win_prob=None, _configuration=None):  # noqa: E501
        """PregameWP - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._season = None
        self._season_type = None
        self._week = None
        self._game_id = None
        self._home_team = None
        self._away_team = None
        self._spread = None
        self._home_win_prob = None
        self.discriminator = None

        if season is not None:
            self.season = season
        if season_type is not None:
            self.season_type = season_type
        if week is not None:
            self.week = week
        if game_id is not None:
            self.game_id = game_id
        if home_team is not None:
            self.home_team = home_team
        if away_team is not None:
            self.away_team = away_team
        if spread is not None:
            self.spread = spread
        if home_win_prob is not None:
            self.home_win_prob = home_win_prob

    @property
    def season(self):
        """Gets the season of this PregameWP.  # noqa: E501


        :return: The season of this PregameWP.  # noqa: E501
        :rtype: int
        """
        return self._season

    @season.setter
    def season(self, season):
        """Sets the season of this PregameWP.


        :param season: The season of this PregameWP.  # noqa: E501
        :type: int
        """

        self._season = season

    @property
    def season_type(self):
        """Gets the season_type of this PregameWP.  # noqa: E501


        :return: The season_type of this PregameWP.  # noqa: E501
        :rtype: str
        """
        return self._season_type

    @season_type.setter
    def season_type(self, season_type):
        """Sets the season_type of this PregameWP.


        :param season_type: The season_type of this PregameWP.  # noqa: E501
        :type: str
        """

        self._season_type = season_type

    @property
    def week(self):
        """Gets the week of this PregameWP.  # noqa: E501


        :return: The week of this PregameWP.  # noqa: E501
        :rtype: int
        """
        return self._week

    @week.setter
    def week(self, week):
        """Sets the week of this PregameWP.


        :param week: The week of this PregameWP.  # noqa: E501
        :type: int
        """

        self._week = week

    @property
    def game_id(self):
        """Gets the game_id of this PregameWP.  # noqa: E501


        :return: The game_id of this PregameWP.  # noqa: E501
        :rtype: int
        """
        return self._game_id

    @game_id.setter
    def game_id(self, game_id):
        """Sets the game_id of this PregameWP.


        :param game_id: The game_id of this PregameWP.  # noqa: E501
        :type: int
        """

        self._game_id = game_id

    @property
    def home_team(self):
        """Gets the home_team of this PregameWP.  # noqa: E501


        :return: The home_team of this PregameWP.  # noqa: E501
        :rtype: str
        """
        return self._home_team

    @home_team.setter
    def home_team(self, home_team):
        """Sets the home_team of this PregameWP.


        :param home_team: The home_team of this PregameWP.  # noqa: E501
        :type: str
        """

        self._home_team = home_team

    @property
    def away_team(self):
        """Gets the away_team of this PregameWP.  # noqa: E501


        :return: The away_team of this PregameWP.  # noqa: E501
        :rtype: str
        """
        return self._away_team

    @away_team.setter
    def away_team(self, away_team):
        """Sets the away_team of this PregameWP.


        :param away_team: The away_team of this PregameWP.  # noqa: E501
        :type: str
        """

        self._away_team = away_team

    @property
    def spread(self):
        """Gets the spread of this PregameWP.  # noqa: E501


        :return: The spread of this PregameWP.  # noqa: E501
        :rtype: float
        """
        return self._spread

    @spread.setter
    def spread(self, spread):
        """Sets the spread of this PregameWP.


        :param spread: The spread of this PregameWP.  # noqa: E501
        :type: float
        """

        self._spread = spread

    @property
    def home_win_prob(self):
        """Gets the home_win_prob of this PregameWP.  # noqa: E501


        :return: The home_win_prob of this PregameWP.  # noqa: E501
        :rtype: float
        """
        return self._home_win_prob

    @home_win_prob.setter
    def home_win_prob(self, home_win_prob):
        """Sets the home_win_prob of this PregameWP.


        :param home_win_prob: The home_win_prob of this PregameWP.  # noqa: E501
        :type: float
        """

        self._home_win_prob = home_win_prob

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PregameWP, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PregameWP):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PregameWP):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cfbd.configuration import Configuration


class GameLines(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'season': 'int',
        'week': 'int',
        'season_type': 'str',
        'home_team': 'str',
        'home_conference': 'str',
        'home_score': 'int',
        'away_team': 'str',
        'away_conference': 'str',
        'away_score': 'int',
        'lines': 'list[object]'
    }

    attribute_map = {
        'id': 'id',
        'season': 'season',
        'week': 'week',
        'season_type': 'seasonType',
        'home_team': 'homeTeam',
        'home_conference': 'homeConference',
        'home_score': 'homeScore',
        'away_team': 'awayTeam',
        'away_conference': 'awayConference',
        'away_score': 'awayScore',
        'lines': 'lines'
    }

    def __init__(self, id=None, season=None, week=None, season_type=None, home_team=None, home_conference=None, home_score=None, away_team=None, away_conference=None, away_score=None, lines=None, _configuration=None):  # noqa: E501
        """GameLines - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._season = None
        self._week = None
        self._season_type = None
        self._home_team = None
        self._home_conference = None
        self._home_score = None
        self._away_team = None
        self._away_conference = None
        self._away_score = None
        self._lines = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if season is not None:
            self.season = season
        if week is not None:
            self.week = week
        if season_type is not None:
            self.season_type = season_type
        if home_team is not None:
            self.home_team = home_team
        if home_conference is not None:
            self.home_conference = home_conference
        if home_score is not None:
            self.home_score = home_score
        if away_team is not None:
            self.away_team = away_team
        if away_conference is not None:
            self.away_conference = away_conference
        if away_score is not None:
            self.away_score = away_score
        if lines is not None:
            self.lines = lines

    @property
    def id(self):
        """Gets the id of this GameLines.  # noqa: E501


        :return: The id of this GameLines.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GameLines.


        :param id: The id of this GameLines.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def season(self):
        """Gets the season of this GameLines.  # noqa: E501


        :return: The season of this GameLines.  # noqa: E501
        :rtype: int
        """
        return self._season

    @season.setter
    def season(self, season):
        """Sets the season of this GameLines.


        :param season: The season of this GameLines.  # noqa: E501
        :type: int
        """

        self._season = season

    @property
    def week(self):
        """Gets the week of this GameLines.  # noqa: E501


        :return: The week of this GameLines.  # noqa: E501
        :rtype: int
        """
        return self._week

    @week.setter
    def week(self, week):
        """Sets the week of this GameLines.


        :param week: The week of this GameLines.  # noqa: E501
        :type: int
        """

        self._week = week

    @property
    def season_type(self):
        """Gets the season_type of this GameLines.  # noqa: E501


        :return: The season_type of this GameLines.  # noqa: E501
        :rtype: str
        """
        return self._season_type

    @season_type.setter
    def season_type(self, season_type):
        """Sets the season_type of this GameLines.


        :param season_type: The season_type of this GameLines.  # noqa: E501
        :type: str
        """

        self._season_type = season_type

    @property
    def home_team(self):
        """Gets the home_team of this GameLines.  # noqa: E501


        :return: The home_team of this GameLines.  # noqa: E501
        :rtype: str
        """
        return self._home_team

    @home_team.setter
    def home_team(self, home_team):
        """Sets the home_team of this GameLines.


        :param home_team: The home_team of this GameLines.  # noqa: E501
        :type: str
        """

        self._home_team = home_team

    @property
    def home_conference(self):
        """Gets the home_conference of this GameLines.  # noqa: E501


        :return: The home_conference of this GameLines.  # noqa: E501
        :rtype: str
        """
        return self._home_conference

    @home_conference.setter
    def home_conference(self, home_conference):
        """Sets the home_conference of this GameLines.


        :param home_conference: The home_conference of this GameLines.  # noqa: E501
        :type: str
        """

        self._home_conference = home_conference

    @property
    def home_score(self):
        """Gets the home_score of this GameLines.  # noqa: E501


        :return: The home_score of this GameLines.  # noqa: E501
        :rtype: int
        """
        return self._home_score

    @home_score.setter
    def home_score(self, home_score):
        """Sets the home_score of this GameLines.


        :param home_score: The home_score of this GameLines.  # noqa: E501
        :type: int
        """

        self._home_score = home_score

    @property
    def away_team(self):
        """Gets the away_team of this GameLines.  # noqa: E501


        :return: The away_team of this GameLines.  # noqa: E501
        :rtype: str
        """
        return self._away_team

    @away_team.setter
    def away_team(self, away_team):
        """Sets the away_team of this GameLines.


        :param away_team: The away_team of this GameLines.  # noqa: E501
        :type: str
        """

        self._away_team = away_team

    @property
    def away_conference(self):
        """Gets the away_conference of this GameLines.  # noqa: E501


        :return: The away_conference of this GameLines.  # noqa: E501
        :rtype: str
        """
        return self._away_conference

    @away_conference.setter
    def away_conference(self, away_conference):
        """Sets the away_conference of this GameLines.


        :param away_conference: The away_conference of this GameLines.  # noqa: E501
        :type: str
        """

        self._away_conference = away_conference

    @property
    def away_score(self):
        """Gets the away_score of this GameLines.  # noqa: E501


        :return: The away_score of this GameLines.  # noqa: E501
        :rtype: int
        """
        return self._away_score

    @away_score.setter
    def away_score(self, away_score):
        """Sets the away_score of this GameLines.


        :param away_score: The away_score of this GameLines.  # noqa: E501
        :type: int
        """

        self._away_score = away_score

    @property
    def lines(self):
        """Gets the lines of this GameLines.  # noqa: E501


        :return: The lines of this GameLines.  # noqa: E501
        :rtype: list[object]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """Sets the lines of this GameLines.


        :param lines: The lines of this GameLines.  # noqa: E501
        :type: list[object]
        """

        self._lines = lines

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GameLines, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GameLines):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GameLines):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.api.recruiting_api import RecruitingApi  # noqa: E501
from cfbd.rest import ApiException


class TestRecruitingApi(unittest.TestCase):
    """RecruitingApi unit test stubs"""

    def setUp(self):
        self.api = cfbd.api.recruiting_api.RecruitingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_recruiting_groups(self):
        """Test case for get_recruiting_groups

        Recruit position group ratings  # noqa: E501
        """
        pass

    def test_get_recruiting_players(self):
        """Test case for get_recruiting_players

        Player recruiting ratings and rankings  # noqa: E501
        """
        pass

    def test_get_recruiting_teams(self):
        """Test case for get_recruiting_teams

        Team recruiting rankings and ratings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  Please note that API keys should be supplied with \"Bearer \" prepended (e.g. \"Bearer your_key\").  # noqa: E501

    OpenAPI spec version: 3.2.0
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from cfbd.api.betting_api import BettingApi
from cfbd.api.coaches_api import CoachesApi
from cfbd.api.conferences_api import ConferencesApi
from cfbd.api.drives_api import DrivesApi
from cfbd.api.games_api import GamesApi
from cfbd.api.metrics_api import MetricsApi
from cfbd.api.players_api import PlayersApi
from cfbd.api.plays_api import PlaysApi
from cfbd.api.rankings_api import RankingsApi
from cfbd.api.ratings_api import RatingsApi
from cfbd.api.recruiting_api import RecruitingApi
from cfbd.api.stats_api import StatsApi
from cfbd.api.teams_api import TeamsApi
from cfbd.api.venues_api import VenuesApi

# import ApiClient
from cfbd.api_client import ApiClient
from cfbd.configuration import Configuration
# import models into sdk package
from cfbd.models.advanced_game_stat import AdvancedGameStat
from cfbd.models.advanced_season_stat import AdvancedSeasonStat
from cfbd.models.box_score import BoxScore
from cfbd.models.coach import Coach
from cfbd.models.conference import Conference
from cfbd.models.conference_sp_rating import ConferenceSPRating
from cfbd.models.drive import Drive
from cfbd.models.game import Game
from cfbd.models.game_lines import GameLines
from cfbd.models.game_media import GameMedia
from cfbd.models.game_ppa import GamePPA
from cfbd.models.play import Play
from cfbd.models.play_stat import PlayStat
from cfbd.models.play_stat_type import PlayStatType
from cfbd.models.play_type import PlayType
from cfbd.models.play_wp import PlayWP
from cfbd.models.player import Player
from cfbd.models.player_game import PlayerGame
from cfbd.models.player_game_ppa import PlayerGamePPA
from cfbd.models.player_search_result import PlayerSearchResult
from cfbd.models.player_season_ppa import PlayerSeasonPPA
from cfbd.models.player_season_stat import PlayerSeasonStat
from cfbd.models.player_usage import PlayerUsage
from cfbd.models.position_group_recruiting_rating import PositionGroupRecruitingRating
from cfbd.models.predicted_points import PredictedPoints
from cfbd.models.pregame_wp import PregameWP
from cfbd.models.ranking_week import RankingWeek
from cfbd.models.recruit import Recruit
from cfbd.models.returning_production import ReturningProduction
from cfbd.models.team import Team
from cfbd.models.team_game import TeamGame
from cfbd.models.team_matchup import TeamMatchup
from cfbd.models.team_ppa import TeamPPA
from cfbd.models.team_record import TeamRecord
from cfbd.models.team_recruiting_rank import TeamRecruitingRank
from cfbd.models.team_sp_rating import TeamSPRating
from cfbd.models.team_srs_rating import TeamSRSRating
from cfbd.models.team_season import TeamSeason
from cfbd.models.team_season_stat import TeamSeasonStat
from cfbd.models.team_talent import TeamTalent
from cfbd.models.venue import Venue
from cfbd.models.week import Week



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.4.1
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BoxScoreTeamsScoringOpportunities(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'team': 'str',
        'opportunities': 'int',
        'points': 'int',
        'points_per_opportunity': 'float'
    }

    attribute_map = {
        'team': 'team',
        'opportunities': 'opportunities',
        'points': 'points',
        'points_per_opportunity': 'pointsPerOpportunity'
    }

    def __init__(self, team=None, opportunities=None, points=None, points_per_opportunity=None):  # noqa: E501
        """BoxScoreTeamsScoringOpportunities - a model defined in Swagger"""  # noqa: E501

        self._team = None
        self._opportunities = None
        self._points = None
        self._points_per_opportunity = None
        self.discriminator = None

        if team is not None:
            self.team = team
        if opportunities is not None:
            self.opportunities = opportunities
        if points is not None:
            self.points = points
        if points_per_opportunity is not None:
            self.points_per_opportunity = points_per_opportunity

    @property
    def team(self):
        """Gets the team of this BoxScoreTeamsScoringOpportunities.  # noqa: E501


        :return: The team of this BoxScoreTeamsScoringOpportunities.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this BoxScoreTeamsScoringOpportunities.


        :param team: The team of this BoxScoreTeamsScoringOpportunities.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def opportunities(self):
        """Gets the opportunities of this BoxScoreTeamsScoringOpportunities.  # noqa: E501


        :return: The opportunities of this BoxScoreTeamsScoringOpportunities.  # noqa: E501
        :rtype: int
        """
        return self._opportunities

    @opportunities.setter
    def opportunities(self, opportunities):
        """Sets the opportunities of this BoxScoreTeamsScoringOpportunities.


        :param opportunities: The opportunities of this BoxScoreTeamsScoringOpportunities.  # noqa: E501
        :type: int
        """

        self._opportunities = opportunities

    @property
    def points(self):
        """Gets the points of this BoxScoreTeamsScoringOpportunities.  # noqa: E501


        :return: The points of this BoxScoreTeamsScoringOpportunities.  # noqa: E501
        :rtype: int
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this BoxScoreTeamsScoringOpportunities.


        :param points: The points of this BoxScoreTeamsScoringOpportunities.  # noqa: E501
        :type: int
        """

        self._points = points

    @property
    def points_per_opportunity(self):
        """Gets the points_per_opportunity of this BoxScoreTeamsScoringOpportunities.  # noqa: E501


        :return: The points_per_opportunity of this BoxScoreTeamsScoringOpportunities.  # noqa: E501
        :rtype: float
        """
        return self._points_per_opportunity

    @points_per_opportunity.setter
    def points_per_opportunity(self, points_per_opportunity):
        """Sets the points_per_opportunity of this BoxScoreTeamsScoringOpportunities.


        :param points_per_opportunity: The points_per_opportunity of this BoxScoreTeamsScoringOpportunities.  # noqa: E501
        :type: float
        """

        self._points_per_opportunity = points_per_opportunity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BoxScoreTeamsScoringOpportunities, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BoxScoreTeamsScoringOpportunities):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
